@@ -1,9 +1,9 @@
 package Music::CreatingRhythms;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Perl from the C code of the book
+# ABSTRACT: Ported Perl from the book's C code
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
 
 use Moo;
 use strictures 2;
@@ -430,11 +430,11 @@ __END__
 
 =head1 NAME
 
-Music::CreatingRhythms - Perl from the C code of the book
+Music::CreatingRhythms - Ported Perl from the book's C code
 
 =head1 VERSION
 
-version 0.0100
+version 0.0101
 
 =head1 SYNOPSIS
 
@@ -451,8 +451,8 @@ link below for more information.
 
 NB: Arguments are sometimes switched between book and software.
 
-Additionally, this module provides utilities to transform sequences
-that are not part of the book, but are nonetheless handy.
+Additionally, this module provides utilities that are not part of the
+book, but are nonetheless handy.
 
 =head1 ATTRIBUTES
 
@@ -474,16 +474,17 @@ Create a new C<Music::CreatingRhythms> object.
 
 =head2 chsequl
 
-  $compositions = $mcr->chsequl($n);
+  $sequence = $mcr->chsequl($t, $p, $q);
+  $sequence = $mcr->chsequl($t, $p, $q, $n);
 
 Generate the upper or lower Christoffel word for p/q
 
 Arguments:
 
-  t = required type of word (u: upper, l: lower)
-  p = required numerator of slope
-  q = required denominator of slope
-  n = optional number of terms to generate, default: p+q
+  $t: required type of word (u: upper, l: lower)
+  $p: required numerator of slope
+  $q: required denominator of slope
+  $n: optional number of terms to generate, default: p+q
 
 =head2 comp
 
@@ -608,7 +609,7 @@ Rotate a necklace of the given B<parts>, B<n> times.
 
 L<https://abrazol.com/books/rhythm1/> "Creating Rhythms"
 
-The F<t/01-methods.t> and F<eg/*> programs included with this distribution.
+The F<t/01-methods.t> program included with this distribution.
 
 L<Algorithm::Combinatorics>
 
